@@ -6,10 +6,8 @@ from bs4 import BeautifulSoup
 
 import requests
 
-def get_soup(champion: str, role: str):
-    url = f"https://app.mobalytics.gg/lol/champions/{champion}/build?role={role}"
-    page = requests.get(url)
-    return BeautifulSoup(page.content, "html.parser")
+
+
 
 def mobalytics_scraper(champion: str, role: str, matchup: str, verbose: bool) -> Node:
     """Scrapes a build from Mobalytics.gg."""
@@ -19,13 +17,10 @@ def mobalytics_scraper(champion: str, role: str, matchup: str, verbose: bool) ->
     # when this happens, just redirect to the most popular allowed role ?
     # check if valid
     matches = soup.find_all("div", class_="css-jboygh e3vq2as0")
-    not_allowed = []
-    for entry in matches:
-        p = entry.find("img")["alt"].lower()
-        not_allowed.append(p)
+    not_allowed = [entry.find("img")["alt"].lower() for entry in matches]
 
     if role in not_allowed:
-        print(f"Mobalytics dosen't have a build for {role}. \nHere's the default build instead.")
+        print(f"Mobalytics doesn't have a build for {role}. \nHere's the default build instead.")
         role = ""
         soup = get_soup(champion, role)
 
@@ -33,15 +28,12 @@ def mobalytics_scraper(champion: str, role: str, matchup: str, verbose: bool) ->
     r = soup.find("div", class_="css-p3pzap eo6ba8g5").text
 
     # create tree entries for default output
-    title = f"{c} {r} from Mobalytics"
-    root = Node(title)
+    root = Node(f"{c} {r} from Mobalytics")
 
     # get the runes
     runes = Node("Runes", parent=root)
     matches = soup.find_all("img", class_="css-1la33yl e16p94fx0")
-    for entry in matches:
-        r = entry["alt"]
-        Node(r, parent=runes)
+    [Node(entry["alt"], parent=runes) for entry in matches]
 
     # get the shards
     matches = soup.find_all("img", class_="css-1vgqbrs ed9gm2s1")
@@ -53,15 +45,15 @@ def mobalytics_scraper(champion: str, role: str, matchup: str, verbose: bool) ->
         "5007": "Ability Haste",
         "5008": "Adaptive Force",
     }
-    # if verbose:
-    #     shards = Node("Shards", parent=root)
+    if verbose:
+        shards = Node("Shards", parent=root)
     for entry in matches:
         shard_id = entry["src"].split(".png")[0][-4:]  # was blah/####.png
         shard = conversion.get(shard_id)
-        # if verbose:
-        #     Node(shard, parent=shards)
-        # else:
-        #     Node(shard, parent=runes)
+        if verbose:
+            Node(shard, parent=shards)
+        else:
+            Node(shard, parent=runes)
         Node(shard, parent=runes)
     
     # get the build
@@ -69,10 +61,7 @@ def mobalytics_scraper(champion: str, role: str, matchup: str, verbose: bool) ->
 
     # get time targets
     if verbose:
-        time_targets = []
-        matches = soup.find_all("p", class_="css-1ofmdln ehobrmq7")
-        for entry in matches:
-            time_targets.append(entry.text)
+        time_targets = [entry.text for entry in soup.find_all("p", class_="css-1ofmdln ehobrmq7")]
 
     # add all relevant entries
     for cycle, entry in enumerate(soup.find_all("div", class_="ednsys62 css-1taoj5l ehobrmq2")):
@@ -107,6 +96,14 @@ def mobalytics_scraper(champion: str, role: str, matchup: str, verbose: bool) ->
         for entry in soup.find_all("div", class_="css-143dzw8 es5thxd2"):
             Node(re.findall(r"alt=\"(.*)\" c", str(entry.contents[0]))[0], situational)
 
+    summoners = Node("Summoner Spells", parent=root)
+    matches = soup.find_all("img", class_="css-1xsdwvo edxc7l62")
+    for entry in matches:
+        s = entry["src"].split(".png")[0].split("Summoner")[1] # was blah/SummonerFoo.png
+        if s == "Dot":
+            s = "Ignite"
+        Node(s, parent=summoners)
+
     # Skill Learn Order
     # for entry in soup.find_all("div", class_="css-70qvj9 ek7zqkr0")[0].contents:
     #     if entry.name == "p":
@@ -115,9 +112,7 @@ def mobalytics_scraper(champion: str, role: str, matchup: str, verbose: bool) ->
     # Skill Max Order
     skill = Node("Skill Priority", parent=root)
     # this makes a list of the skill taken at each level
-    sequence = []
-    for entry in soup.find_all("div", class_="css-1dai7ia eaoplg14"):
-        sequence.append(entry.text) 
+    sequence = [entry.text for entry in soup.find_all("div", class_="css-1dai7ia eaoplg14")]
     # this dict has Q W E keys and values of the level when they get maxed
     max_order = {}
     for ability in ["Q", "W", "E"]:
@@ -132,3 +127,8 @@ def mobalytics_scraper(champion: str, role: str, matchup: str, verbose: bool) ->
         
     # return tree
     return root
+
+def get_soup(champion: str, role: str) -> BeautifulSoup:
+    url = f"https://app.mobalytics.gg/lol/champions/{champion}/build?role={role}"
+    page = requests.get(url)
+    return BeautifulSoup(page.content, "html.parser")
\ No newline at end of file
